.. image:: https://badge.fury.io/py/planetmint-cryptoconditions.svg
        :target: https://badge.fury.io/py/planetmint-cryptoconditions

.. image:: https://app.travis-ci.com/planetmint/cryptoconditions.svg?branch=main
        :target: https://app.travis-ci.com/planetmint/cryptoconditions

.. image:: https://codecov.io/gh/planetmint/cryptoconditions/branch/main/graph/badge.svg?token=2Bo1knLW0Q
        :target: https://codecov.io/gh/planetmint/cryptoconditions
    
The cryptoconditions Package
============================

A Python implementation of the Crypto-Conditions spec: a multi-algorithm, multi-level, multi-signature format for expressing conditions and fulfillments.

This implementation doesn't implement the entire Crypto-Conditions spec. It implements the conditions needed by BigchainDB, and some others. It's compliant with `version 02 <https://tools.ietf.org/html/draft-thomas-crypto-conditions-02>`_ and `version 03 <https://tools.ietf.org/html/draft-thomas-crypto-conditions-02>`_ of the spec.

See also: the `rfcs/crypto-conditions repository <https://github.com/rfcs/crypto-conditions>`_.

Installation
------------

To install latest release from PyPI:

.. code-block:: bash

    $ pip install planetmint-cryptoconditions

Documentation
-------------

See `https://cryptoconditions.readthedocs.io/en/latest/ <https://cryptoconditions.readthedocs.io/en/latest/>`_.
